/*
 * dist.c
 * 2015/7/25 ymaslenko $
 * help funtions for fragment distance
 */
#ifndef _XOPEN_SOURCE
#   define _XOPEN_SOURCE 500                 /* Necessary on sun to get M_PI */
#endif

#include <math.h>
#include <stdio.h>
#include "bad_angle.h"
#include "coord.h"
#include "coord_i.h"
#include "sec_s_i.h"
#include "dist.h"

/* Notes...
 * This file may be called from programs other than wurst.
 * Do not make it rely on any really secret files.
 */
/* ---------------- Local Constants   -------------------------*/

static const float MAX_CA_CA2 = 4.0 * 4.0;
/* max dist between CA atoms squared */
static const float MIN_CA_CA2 = 2.3 * 2.3; /* min dist between CA atoms squared */

/* ---------------- dist_frag_coord -----------------------------
 * Distance for a fragment
 * distance from ca-Atom of the first C-Atom to
 * the ca-Atom of the last C-Atom in the fragment
 */
float
dist_frag_coord(struct coord *c,
                const size_t idx,
                const unsigned int frag_length,
                const unsigned int sqrt_flag) {
    float distance = 0.0;
    short diff_origins = 0;
    float fragment_distance = 0.0;

    if (idx < 0 || idx >= c->size - 1 || idx > c->size - frag_length) {
        return BAD_DISTANCE_FLOAT;
    }

    /*check only fragment start and fragment end*/
    size_t i;
    for (i = 0; i < 1; i++) {
        distance = coord_ca_ca_dist(c, idx + i, idx + i + 1, 0);
        diff_origins = c->orig[idx + i + 1] - c->orig[idx + i];
        if (distance <= MIN_CA_CA2
            || distance >= MAX_CA_CA2
            || diff_origins != 1) {
            return BAD_DISTANCE_FLOAT;
        }
    }

    size_t k;
    for (k = frag_length - 2; k < frag_length - 1; k++) {
        distance = coord_ca_ca_dist(c, idx + k, idx + k + 1, 0);
        diff_origins = c->orig[idx + k + 1] - c->orig[idx + k];
        if (distance <= MIN_CA_CA2
            || distance >= MAX_CA_CA2
            || diff_origins != 1
                ) {
            return BAD_DISTANCE_FLOAT;
        }
    }

    /*check the whole fragment*/
    /*size_t i;
    for (i = 0; i < frag_length - 1; i++) {
        distance = coord_ca_ca_dist(c, idx + i, idx + i + 1, 0);
        diff_origins = c->orig[idx + i + 1] - c->orig[idx + i];
        if (distance <= MIN_CA_CA2
            || distance >= MAX_CA_CA2
            || diff_origins != 1) {
            return BAD_DISTANCE_FLOAT;
        }
    }*/

    fragment_distance = coord_ca_ca_dist(c, idx, idx + frag_length - 1, 0);
    if (fragment_distance == 0.0 || fragment_distance < 0.0) {
        fragment_distance = BAD_DISTANCE_FLOAT;
    } else if (sqrt_flag) {
        fragment_distance = sqrt(fragment_distance);
    }

    return fragment_distance;
}
